=== modified file 'tests/dbqp.py'
--- tests/dbqp.py	2011-01-27 20:13:55 +0000
+++ tests/dbqp.py	2011-01-30 20:29:00 +0000
@@ -81,6 +81,6 @@
 finally:
 # TODO - make a more robust cleanup
 # At the moment, runaway servers are our biggest concern
-    if server_manager:
+    if server_manager and not variables['startandexit']:
         server_manager.cleanup()
 

=== modified file 'tests/lib/test_mgmt/execution_management.py'
--- tests/lib/test_mgmt/execution_management.py	2011-01-27 20:13:55 +0000
+++ tests/lib/test_mgmt/execution_management.py	2011-01-30 20:29:00 +0000
@@ -53,12 +53,20 @@
                          , 'executors'
                          , 'executor_start_count'
                          , 'executor_current_count'
+                         , 'record_flag'
+                         , 'start_and_exit'
                          ]
         
         self.debug = variables['debug']
         self.verbose = variables['verbose']
         self.force = variables['force']
         self.record_flag = variables['record']
+        # We are currently single-threaded execution-wise
+        # but in the future, we will likely need to revamp
+        # how we deal with start-and-exit if we have multiple
+        # executors - even if we force-set the executor-count
+        # to 1.
+        self.start_and_exit = variables['startandexit']
         self.executors = {}
         self.executor_name_base = 'testbot'
         self.executor_start_count = 0
@@ -91,7 +99,7 @@
             if self.verbose:
                 self.logging.verbose("Starting executor: %s" %(executor_name))
                 # thread.start_new(executor.execute,()) # sigh...one day...damned drizzletest!
-            executor.execute()
+            executor.execute(self.start_and_exit)
         time.sleep(3)
         while self.has_running_executors():
             pass

=== modified file 'tests/lib/test_mgmt/test_execution.py'
--- tests/lib/test_mgmt/test_execution.py	2011-01-28 20:45:12 +0000
+++ tests/lib/test_mgmt/test_execution.py	2011-01-30 20:29:00 +0000
@@ -30,6 +30,7 @@
 
 # imports
 import os
+import sys
 
 class testExecutor():
     """ class for handling the execution of testCase
@@ -113,7 +114,7 @@
 
         return(master_count, slave_count, server_options)
 
-    def execute(self):
+    def execute(self, start_and_exit):
         """ Execute a test case.  The details are *very* mode specific """
         self.status = 1 # we are running
         keep_running = 1
@@ -129,6 +130,10 @@
                 self.current_test_status = 'fail'
                 self.set_server_status(self.current_test_status)
                 output = ''
+            if start_and_exit:
+                # TODO:  Report out all started servers via server_manager/server objects?
+                self.logging.info("User specified --start-and-exit.  dbqp.py exiting and leaving servers running...")
+                sys.exit(0)
             else:
                 self.execute_testCase()
             self.test_manager.record_test_result( self.current_testcase

=== modified file 'tests/lib/test_run_options.py'
--- tests/lib/test_run_options.py	2011-01-29 20:26:04 +0000
+++ tests/lib/test_run_options.py	2011-01-30 20:29:00 +0000
@@ -85,6 +85,14 @@
  )
 
 system_control_group.add_option(
+    "--start-and-exit"
+  , dest="startandexit"
+  , action="store_true"
+  , default=False
+  , help="Spin up the server(s) for the first specified test then exit (will leave servers running)"
+  )
+
+system_control_group.add_option(
     "--verbose"
    , dest="verbose"
    , action="store_true"

